@@ -5,7 +5,7 @@ package App::Cmd::Simple;
 use App::Cmd::Command;
 BEGIN { our @ISA = 'App::Cmd::Command' }
 
-our $VERSION = '0.299_01';
+our $VERSION = '0.010';
 
 use App::Cmd;
 use Sub::Install;
@@ -103,16 +103,10 @@ sub import {
   return if $class eq __PACKAGE__;
 
   # This signals that something has already set the target up.
-  return $class if $class->_cmd_pkg;
-
-  my $core_execute = App::Cmd::Command->can('execute');
-  my $our_execute  = $class->can('execute');
-  Carp::confess(
-    "App::Cmd::Simple subclasses must implement ->execute, not ->run"
-  ) unless $our_execute and $our_execute != $core_execute;
+  return if $class->_cmd_pkg;
 
   # I doubt the $i will ever be needed, but let's start paranoid.
-  my $generated_name = join('::', $class, '_App_Cmd', $i++);
+  my $generated_name = join('::', $class, 'Cmd', $i++);
 
   {
     no strict 'refs';
@@ -125,6 +119,12 @@ sub import {
     code => sub { $generated_name },
   });
 
+  Sub::Install::reinstall_sub({
+    into => $class,
+    as   => "__$i", # cheap trick -- rjbs, 2007-10-09
+    code => $class->can('run'),
+  });
+
   Sub::Install::install_sub({
     into => $generated_name,
     as   => '_command',
@@ -147,18 +147,19 @@ sub import {
     },
   });
 
-  Sub::Install::install_sub({
-    into => $class,
-    as   => 'run',
-    code => sub {
-      $generated_name->new({
+  # required to make compilation packages correct for caller
+  eval qq[
+    no warnings 'redefine';
+    package $class;
+    sub run {
+      my \$caller = caller;
+      return shift->__$i(\@_) if \$caller eq 'App::Cmd';
+      return ${generated_name}->new({
         no_help_plugin     => 1,
         no_commands_plugin => 1,
-      })->run(@_);
+      })->run(\@_);
     }
-  });
-
-  return $class;
+  ];
 }
 
 sub usage_desc {
@@ -180,12 +181,6 @@ something other than writing a fairly simple command, and you want to screw
 around with the App::Cmd-iness of your program, Simple might not be the best
 choice.
 
-B<One specific warning...>  if you are writing a program with the
-App::Cmd::Simple class embedded in it, you B<must> call import on the class.
-That's how things work.  You can just do this:
-
-  YourApp::Cmd->import->run;
-
 =head1 AUTHOR AND COPYRIGHT
 
 Copyright 2007, (code (simply)).  All rights reserved;  App::Cmd and
